
! $Id: $
MODULE inifis_mod

  IMPLICIT NONE
  ! for now constants and flags transmitted from dyn to phys are stored here
!  REAL,SAVE    :: daysec ! length of reference day (s)
!  REAL,SAVE    :: dtphys ! physics time step (s)
!  INTEGER,SAVE :: day_step ! number of physical steps per day
!  INTEGER,SAVE :: nday ! number of days to run
!!$OMP THREADPRIVATE(daysec,dtphys,day_step,iphysiq,dayref,anneeref,nday)
!  INTEGER,SAVE :: annee_ref ! reference year as read from start file
!  INTEGER,SAVE :: day_ini
!  INTEGER,SAVE :: day_end
!!$OMP THREADPRIVATE(annee_ref,day_ini,day_end)
!  INTEGER,SAVE :: itau_phy   ! number of physiq iteration from origin
!  INTEGER,SAVE :: itaufin    ! final iteration 
!  REAL,SAVE    :: start_time
!  INTEGER,SAVE :: day_ref
!  REAL,SAVE :: jD_ref
!!$OMP THREADPRIVATE(itau_phy,itaufin,start_time,day_ref,JD_ref)
!  INTEGER,SAVE :: raz_date
!  INTEGER,SAVE :: lunout=6 ! default output file identifier (6==screen)
!  INTEGER,SAVE :: prt_level ! Output level
!  LOGICAL,SAVE :: debug ! flag to specify if in "debug mode"
!!$OMP THREADPRIVATE(lunout,prt_level,debug)

CONTAINS

  SUBROUTINE inifis(punjours, prad,pg,pr,pcpp)
  ! Initialize physics constant and flags from dynamics
  USE init_print_control_mod, ONLY : init_print_control
  USE print_control_mod, ONLY : lunout
  USE phystokenc_mod, only: init_phystokenc
  IMPLICIT NONE

  include "YOMCST.h"
  REAL,INTENT(IN) :: punjours, prad, pg, pr, pcpp
  CHARACTER (LEN=20) :: modname = 'inifis'
  CHARACTER (LEN=80) :: abort_message

  CALL init_print_control

  ! suphel => initialize some physical constants (orbital parameters,
  !           geoid, gravity, thermodynamical constants, etc.) in the
  !           physics
  CALL suphel

  ! check that physical constants set in 'suphel' are coherent
  ! with values set in the dynamics:
  IF (rday/=punjours) THEN
    WRITE (lunout, *) 'inifis: length of day discrepancy!!!'
    WRITE (lunout, *) '  in the dynamics punjours=', punjours
    WRITE (lunout, *) '   but in the physics RDAY=', rday
    IF (abs(rday-punjours)>0.01*punjours) THEN
        ! stop here if the relative difference is more than 1%
      abort_message = 'length of day discrepancy'
      CALL abort_physic(modname, abort_message, 1)
    END IF
  END IF
  IF (rg/=pg) THEN
    WRITE (lunout, *) 'inifis: gravity discrepancy !!!'
    WRITE (lunout, *) '     in the dynamics pg=', pg
    WRITE (lunout, *) '  but in the physics RG=', rg
    IF (abs(rg-pg)>0.01*pg) THEN
        ! stop here if the relative difference is more than 1%
      abort_message = 'gravity discrepancy'
      CALL abort_physic(modname, abort_message, 1)
    END IF
  END IF
  IF (ra/=prad) THEN
    WRITE (lunout, *) 'inifis: planet radius discrepancy !!!'
    WRITE (lunout, *) '   in the dynamics prad=', prad
    WRITE (lunout, *) '  but in the physics RA=', ra
    IF (abs(ra-prad)>0.01*prad) THEN
        ! stop here if the relative difference is more than 1%
      abort_message = 'planet radius discrepancy'
      CALL abort_physic(modname, abort_message, 1)
    END IF
  END IF
  IF (rd/=pr) THEN
    WRITE (lunout, *) 'inifis: reduced gas constant discrepancy !!!'
    WRITE (lunout, *) '     in the dynamics pr=', pr
    WRITE (lunout, *) '  but in the physics RD=', rd
    IF (abs(rd-pr)>0.01*pr) THEN
        ! stop here if the relative difference is more than 1%
      abort_message = 'reduced gas constant discrepancy'
      CALL abort_physic(modname, abort_message, 1)
    END IF
  END IF
  IF (rcpd/=pcpp) THEN
    WRITE (lunout, *) 'inifis: specific heat discrepancy !!!'
    WRITE (lunout, *) '     in the dynamics pcpp=', pcpp
    WRITE (lunout, *) '  but in the physics RCPD=', rcpd
    IF (abs(rcpd-pcpp)>0.01*pcpp) THEN
        ! stop here if the relative difference is more than 1%
      abort_message = 'specific heat discrepancy'
      CALL abort_physic(modname, abort_message, 1)
    END IF
  END IF
  
  CALL init_phystokenc

  END SUBROUTINE inifis

END MODULE inifis_mod
